@@ -1,7 +1,7 @@
-from operations_with_objects.operations_with_objects import OperationsWithObjects
-from operations_with_objects.system_object import SystemObject
-from quick_resto_api import QuickRestoApi
-from quick_resto_objects.modules.core.business import Business
+from quick_resto_API.operations_with_objects.operations_with_objects import OperationsWithObjects
+from quick_resto_API.operations_with_objects.system_object import SystemObject
+from quick_resto_API.quick_resto_api import QuickRestoApi
+from quick_resto_API.quick_resto_objects.modules.core.business import Business
 
 class BusinessOperations(SystemObject):
     def __init__(self, api: QuickRestoApi):
