@@ -1,8 +1,8 @@
-from operations_with_objects.operations_with_objects import OperationsWithObjects
-from operations_with_objects.system_object import SystemObject
-from quick_resto_api import QuickRestoApi
-from quick_resto_objects.modules.front.pos_terminal import PosTerminal
-from quick_resto_objects.modules.front.virtual_pos_terminal import VirtualPosTerminal
+from quick_resto_API.operations_with_objects.operations_with_objects import OperationsWithObjects
+from quick_resto_API.operations_with_objects.system_object import SystemObject
+from quick_resto_API.quick_resto_api import QuickRestoApi
+from quick_resto_API.quick_resto_objects.modules.front.pos_terminal import PosTerminal
+from quick_resto_API.quick_resto_objects.modules.front.virtual_pos_terminal import VirtualPosTerminal
 
 class PosTerminalOperations(SystemObject):
     def __init__(self, api: QuickRestoApi):
