@@ -17,7 +17,7 @@ StrToSystemOrderDiscardReason = {
 
 
 def convert_str_to_system_order_discard_reason(value: str) -> SystemOrderDiscardReason:
-    if value in SystemOrderDiscardReason.keys():
+    if value in StrToSystemOrderDiscardReason.keys():
         return StrToSystemOrderDiscardReason[value]
 
     return SystemOrderDiscardReason.NONE
