@@ -7,7 +7,7 @@ from quick_resto_API.quick_resto_objects.modules.warehouse.sale_place import Sal
 from quick_resto_API.quick_resto_objects.quick_resto_object import QuickRestoObject
 
 
-class TimeRange:
+class TimeRange(object):
     @property
     def start(self) -> str:
         return self._start
@@ -40,7 +40,11 @@ class Day(QuickRestoObject):
 
         self._day: str = day
         self._active: bool = active
-        self._time_range: dict = TimeRange(**timeRange)
+        
+        if timeRange is not None:
+            self._time_range: TimeRange = TimeRange(**timeRange)
+        else:
+            self._time_range = None
 
 
 class Markup(QuickRestoObject):
